Python: module tilestache-compose

tilestache-compose | index

Modules
`` |  |
ModestMaps |  |  |

Classes
`` |  | ModestMaps.Providers.IMapProvider Provider exceptions.Exception(exceptions.BaseException) BadComposure
class BadComposure(exceptions.Exception)
`` |  | Method resolution order: BadComposure exceptions.Exception exceptions.BaseException __builtin__.object Data descriptors defined here: __weakref__ `list of weak references to the object (if defined)` Methods inherited from exceptions.Exception: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes inherited from exceptions.Exception: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from exceptions.BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from exceptions.BaseException: __dict__ args message
class Provider(ModestMaps.Providers.IMapProvider)
`` | `Wrapper for TileStache Layer objects that makes them behave like ModestMaps Provider objects. Requires ModestMaps 1.3.0 or better to support "file://" URLs.`
| Methods defined here: __del__(self) `Delete any tile that was saved in getTileUrls().` __init__(self, layer, verbose=False, ignore_cached=None) getTileUrls(self, coord) `Return tile URLs that start with file://, by first retrieving them.` tileHeight(self) tileWidth(self) Methods inherited from ModestMaps.Providers.IMapProvider: coordinateLocation(self, location) locationCoordinate(self, location) sourceCoordinate(self, coordinate)

Functions
`` |  | allocate_lock(...) `allocate_lock() -> lock object (allocate() is an obsolete synonym) Create a new lock object. See help(LockType) for information about locks.` close(...) `close(fd) Close a file descriptor (for low level IO).` printlocked(lock, *stuff) unlink(...) `unlink(path) Remove a file (same as remove(path)).` write(...) `write(fd, string) -> byteswritten Write a string to a file descriptor.`

Data
`` |  | defaults = {'center': (37.8044, -122.2712), 'dimensions': (900, 600), 'verbose': True, 'zoom': 14} mmaps_version = (1, 4, 6) parser = <optparse.OptionParser instance> path = ['', '/Library/Frameworks/SQLite3.framework/Versions/B/Python/2.7', '/Library/Frameworks/GEOS.framework/Versions/3/Python/2.7', '/Library/Python/2.7/site-packages/numpy-override', '/Library/Frameworks/GDAL.framework/Versions/1.10/Python/2.7/site-packages', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python27.zip', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/plat-darwin', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/plat-mac', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/plat-mac/lib-scriptpackages', '/Users/migurski/Sites/TileStache/venv-tilestache/Extras/lib/python', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/lib-tk', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/lib-old', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/lib-dynload', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/plat-darwin', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/lib-tk', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/plat-mac', '/System/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/plat-mac/lib-scriptpackages', '/Users/migurski/Sites/TileStache/venv-tilestache/lib/python2.7/site-packages', ...] stderr = <open file '<stderr>', mode 'w'>